@@ -1,4 +1,5 @@
-#' Functions to calculate water properties: density, dynamic and kinematic viscosity
+#' Functions to calculate water properties: density, dynamic and kinematic 
+#' viscosity, and saturation vapor pressure
 #'
 #' This function calculates water properties that are used in other functions.
 #'
@@ -17,6 +18,9 @@
 #'
 #' @return nu, the kinematic viscosity of water for the
 #'   kvisc function [\eqn{m^2 s^{-1}}{m^2/s} or \eqn{ft^2 s^{-1}}{ft^2/s}].
+
+#' @return svp, the saturation vapor pressure of water for the
+#'   svp function [\eqn{N/m^2}{N/m^2} or \eqn{lbf/ft^2}{lbf/ft^2}].
 #'
 #' @author Ed Maurer
 #'
@@ -30,6 +34,9 @@
 #'
 #' #Find water density for water temperature of 25 C
 #' rho = dens(T = 25, units = 'SI')
+#' 
+#' #Find saturation vapor pressure for water temperature of 10 C
+#' vps = svp(T = 10, units = 'SI')
 #'
 #' @name waterprops
 NULL
@@ -94,7 +101,7 @@ dens <- function(T = NULL, units = c("SI", "Eng"), ret_units = FALSE) {
       message("\nTemperature not given.\nAssuming T = 68 F\n")
       T = 68
     } else if (all(c("SI", "Eng") %in% units == FALSE) == FALSE) {
-      stop("Incorrect unit system. Specifcy either SI or Eng.")
+      stop("Incorrect unit system. Specify either SI or Eng.")
     }
   }
   if (units == "Eng") {
@@ -134,7 +141,7 @@ kvisc <- function(T = NULL, units = c("SI", "Eng"), ret_units = FALSE) {
       message("\nTemperature not given.\nAssuming T = 68 F\n")
       T = 68
     } else if (all(c("SI", "Eng") %in% units == FALSE) == FALSE) {
-      stop("Incorrect unit system. Specifcy either SI or Eng.")
+      stop("Incorrect unit system. Specify either SI or Eng.")
     }
   }
   if (units == "Eng") {
@@ -155,3 +162,43 @@ kvisc <- function(T = NULL, units = c("SI", "Eng"), ret_units = FALSE) {
   }
   return(kvisc)
 }
+#' @export
+#' @rdname waterprops
+svp <- function(T = NULL, units = c("SI", "Eng"), ret_units = FALSE) {
+  # check to make sure that T is given
+  if( class(T) == "units" ) T <- units::drop_units(T)
+  checks <- c(T)
+  units <- units
+  if (length(checks) < 1) {
+    if (units == "SI") {
+      message("\nTemperature not given.\nAssuming T = 20 C\n")
+      T = 20
+    } else if (units == "Eng") {
+      message("\nTemperature not given.\nAssuming T = 68 F\n")
+      T = 68
+    } else if (all(c("SI", "Eng") %in% units == FALSE) == FALSE) {
+      stop("Incorrect unit system. Specify either SI or Eng.")
+    }
+  }
+  if (units == "Eng") {
+    # convert units if necessary
+    T = (T - 32) * 5/9
+  }
+  if (min(T) < 0 | max(T) > 100) {
+    stop("\nTemperature outside range for liquid water.\n")
+  }
+  #Use eq 17 from Huang, 2018, A Simple Accurate Formula for Calculating 
+  #Saturation Vapor Pressure of Water and Ice, Journal of Applied Meteorology 
+  #and Climatology, 57(6), 1265-1272
+  svp <- exp(34.494-4924.99/(T+237.1))/((T+105)^1.57) #result in Pa
+
+  if (units == "Eng") {
+  # for Eng units, convert from Pa to lbf/ft^2
+  svp <- svp * 0.0208854
+  }
+  if( ret_units ) {
+    if (units == "Eng") svp <- units::set_units(svp,"lbf/ft^2")
+    if (units == "SI") svp <- units::set_units(svp,"Pa")
+  }
+  return(svp)
+}
